'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var utils = require('@emotion/utils');
var React = require('react');
var StyleSheet = _interopDefault(require('@emotion/sheet'));
var emotionUtils = require('emotion-utils');

// https://github.com/thysultan/stylis.js/tree/master/plugins/rule-sheet
// inlined to avoid umd wrapper and peerDep warnings/installing stylis
// since we use stylis after closure compiler
var delimiter = '/*|*/';
var needle = delimiter + '}';
function createRuleSheetPlugin(insertRule) {
  function toSheet(block) {
    if (block) {
      insertRule(block + '}');
    }
  }

  return function ruleSheet(context, content, selectors, parents, line, column, length, at, depth) {
    switch (context) {
      case 2:
        if (at === 0) return content + delimiter;
        break;
      // at-rule

      case 3:
        switch (at) {
          // @font-face, @page
          case 102:
          case 112:
            {
              insertRule(selectors[0] + content);
              return '';
            }

          default:
            {
              return content + delimiter;
            }
        }

      case -2:
        {
          content.split(needle).forEach(toSheet);
        }
    }
  };
}

var hydration = {
  shouldHydrate: false
};

if (utils.isBrowser) {
  hydration.shouldHydrate = !!document.querySelector('[data-more]');
}

function _set() {}

function _get() {
  return true;
}

if (process.env.NODE_ENV === 'test') {
  // $FlowFixMe
  Object.defineProperty(hydration, 'shouldHydrate', {
    set: _set,
    get: _get
  });
}

var defaultContext = {
  stylis: new emotionUtils.Stylis({
    keyframe: false,
    global: false,
    semicolon: true
  }),
  sheet: new StyleSheet({
    key: ''
  }),
  inserted: {},
  registered: {},
  theme: {}
};

if (utils.isBrowser) {
  defaultContext.sheet.inject();
}

var current;
var insertionPlugin = createRuleSheetPlugin(function (rule) {
  current.push(rule);
});

var returnFullPlugin = function returnFullPlugin(context) {
  if (context === -1) {
    current = [];
  }

  if (context === -2) {
    return current;
  }
};

defaultContext.stylis.use(insertionPlugin)(returnFullPlugin); // $FlowFixMe

var CSSContext = React.createContext(defaultContext);

exports.hydration = hydration;
exports.CSSContext = CSSContext;
//# sourceMappingURL=index.cjs.js.map
